import { BasePartialBatchProcessor } from './BasePartialBatchProcessor.js';
import { BatchProcessingError } from './errors.js';
/**
 * Process native partial responses from SQS, Kinesis Data Streams, and DynamoDB
 */
class BatchProcessor extends BasePartialBatchProcessor {
    async processRecord(record) {
        try {
            const data = this.toBatchType(record, this.eventType);
            const result = await this.handler(data, this.options?.context);
            return this.successHandler(record, result);
        }
        catch (error) {
            return this.failureHandler(record, error);
        }
    }
    /**
     * Process a record with instance's handler
     * @param _record Batch record to be processed
     * @returns response of success or failure
     */
    processRecordSync(_record) {
        throw new BatchProcessingError('Not implemented. Use asyncProcess() instead.');
    }
}
export { BatchProcessor };
